@@ -101,33 +101,36 @@ BLK_DEVICE_TEMPLATE = """
 {
     "blockdevices": [
         {"kname":"sda", "model":"TinyUSB Drive", "size":3116853504,
-        "rota":false, "type":"disk", "serial":123, "uuid":"F531-BDC3",
+        "rota":false, "type":"disk", "serial":"sda123", "uuid":"F531-BDC3",
         "partuuid":null},
         {"kname":"sdb", "model":"Fastable SD131 7", "size":10737418240,
-        "rota":false, "type":"disk",
+        "rota":false, "type":"disk", "serial":"sdb123",
         "uuid":"9a5e5cca-e03d-4cbd-9054-9e6ca9048222", "partuuid":null},
         {"kname":"sdc", "model":"NWD-BLP4-1600", "size":1765517033472,
-        "rota":false, "type":"disk", "uuid":null, "partuuid":null},
+        "rota":false, "type":"disk", "serial":"sdc123", "uuid":null,
+        "partuuid":null},
         {"kname":"sdd", "model":"NWD-BLP4-1600", "size":1765517033472,
-        "rota":false, "type":"disk", "uuid":null, "partuuid":null},
+        "rota":false, "type":"disk", "serial":"sdd123", "uuid":null,
+        "partuuid":null},
         {"kname":"loop0", "model":null, "size":109109248, "rota":true,
-        "type":"loop", "uuid":null, "partuuid": null},
+        "type":"loop", "serial":null, "uuid":null, "partuuid": null},
         {"kname":"zram0", "model":null, "size":0, "rota":false, "type":"disk",
-        "uuid":null, "partuuid":null},
+        "serial":null, "uuid":null, "partuuid":null},
         {"kname":"ram0", "model":null, "size":8388608, "rota":false,
-        "type":"disk", "uuid":null, "partuuid":null},
+        "type":"disk", "serial":null, "uuid":null, "partuuid":null},
         {"kname":"ram1", "model":null, "size":8388608, "rota":false,
-        "type":"disk", "uuid":null, "partuuid":null},
+        "type":"disk", "serial":null, "uuid":null, "partuuid":null},
         {"kname":"ram2", "model":null, "size":8388608, "rota":false,
-        "type":"disk", "uuid":null, "partuuid":null},
+        "type":"disk", "serial":null,  "uuid":null, "partuuid":null},
         {"kname":"ram3", "model":null, "size":8388608, "rota":false,
-        "type":"disk", "uuid":null, "partuuid":null},
+        "type":"disk", "serial":null, "uuid":null, "partuuid":null},
         {"kname":"fd1", "model":"magic", "size":4096, "rota":true,
-        "type":"disk", "uuid":null, "partuuid":null},
+        "type":"disk", "serial":null, "uuid":null, "partuuid":null},
         {"kname":"sdf", "model":"virtual floppy", "size":0, "rota":true,
-        "type":"disk", "uuid":null, "partuuid":null},
+        "type":"disk", "serial":null, "uuid":null, "partuuid":null},
         {"kname":"dm-0", "model":"NWD-BLP4-1600", "size":"1765517033472",
-        "rota":false, "type":"mpath", "uuid":null, "partuuid":null}
+        "rota":false, "type":"mpath", "serial":null, "uuid":null,
+        "partuuid":null}
     ]
 }
 """
@@ -137,9 +140,22 @@ BLK_DEVICE_TEMPLATE_SMALL = """
 {
   "blockdevices": [
     {"kname":"sda", "model":"TinyUSB Drive", "size":3116853504, "rota":false,
-    "type":"disk", "uuid":"F531-BDC", "partuuid":null},
+    "type":"disk", "serial":"123", "uuid":"F531-BDC", "partuuid":null},
     {"kname":"sdb", "model":"AlmostBigEnough Drive", "size":"4294967295",
-    "rota":false, "type":"disk", "uuid":null, "partuuid":null}
+    "rota":false, "type":"disk", "serial":"456", "uuid":null, "partuuid":null}
+  ]
+}
+"""
+
+
+# NOTE This is intentionally have serials removed
+BLK_INCOMPLETE_DEVICE_TEMPLATE_SMALL = """
+{
+  "blockdevices": [
+    {"kname":"sda", "model":"TinyUSB Drive", "size":3116853504, "rota":false,
+    "type":"disk", "serial":"", "uuid":"F531-BDC", "partuuid":null},
+    {"kname":"sdb", "model":"AlmostBigEnough Drive", "size":"4294967295",
+    "rota":false, "type":"disk", "serial":"", "uuid":null, "partuuid":null}
   ]
 }
 """
@@ -155,23 +171,23 @@ RAID_BLK_DEVICE_TEMPLATE = ("""
 {
     "blockdevices": [
       {"kname":"sda", "model":"DRIVE 0", "size":1765517033472, "rota":true,
-      "type":"disk", "uuid":null, "partuuid":null},
+      "type":"disk", "serial":"sda123", "uuid":null, "partuuid":null},
       {"kname":"sda1", "model":"DRIVE 0", "size":107373133824, "rota":true,
-      "type":"part", "uuid":null, "partuuid":null},
+      "type":"part", "serial":"sda1123", "uuid":null, "partuuid":null},
       {"kname":"sdb", "model":"DRIVE 1", "size":1765517033472, "rota":true,
-      "type":"disk", "uuid":null, "partuuid":null},
+      "type":"disk", "serial":"sdb123", "uuid":null, "partuuid":null},
       {"kname":"sdb", "model":"DRIVE 1", "size":1765517033472, "rota":true,
       "type":"disk", "uuid":null, "partuuid":null},
       {"kname":"sdb1", "model":"DRIVE 1", "size":107373133824, "rota":true,
-      "type":"part", "uuid":null, "partuuid":null},
+      "type":"part", "serial":"sdb1123", "uuid":null, "partuuid":null},
       {"kname":"md0p1", "model":"RAID", "size":107236818944, "rota":false,
-      "type":"md", "uuid":null, "partuuid":null},
+      "type":"md", "serial":null, "uuid":null, "partuuid":null},
       {"kname":"md0", "model":"RAID", "size":1765517033470, "rota":false,
-      "type":"raid1", "uuid":null, "partuuid":null},
+      "type":"raid1", "serial":null, "uuid":null, "partuuid":null},
       {"kname":"md0", "model":"RAID", "size":1765517033470, "rota":false,
-      "type":"raid1", "uuid":null, "partuuid":null},
+      "type":"raid1", "serial":null, "uuid":null, "partuuid":null},
       {"kname":"md1", "model":"RAID", "size":0, "rota":false, "type":"raid1",
-      "uuid":null, "partuuid":null}
+      "serial":null, "uuid":null, "partuuid":null}
     ]
 }
 """)
@@ -180,49 +196,52 @@ MULTIPATH_BLK_DEVICE_TEMPLATE = ("""
 {
     "blockdevices": [
       {"kname":"sda", "model":"INTEL_SSDSC2CT060A3", "size":"60022480896",
-      "rota":false, "type":"disk", "uuid":null, "partuuid":null},
+      "rota":false, "type":"disk", "serial":"sda123", "uuid":null,
+      "partuuid":null},
       {"kname":"sda2", "model":null, "size":"59162722304", "rota":false,
       "type":"part", "uuid":"f8b55d59-96c3-3982-b129-1b6b2ee8da86",
-      "partuuid":"c97c8aac-7796-4433-b1fc-9b5fac43edf3"},
+      "partuuid":"c97c8aac-7796-4433-b1fc-9b5fac43edf3", "serial":"sda2123"},
       {"kname":"sda3", "model":null, "size":"650002432", "rota":false,
       "type":"part", "uuid":"b3b03565-5f13-3c93-b2a6-6d90e25be926",
-      "partuuid":"6c85beff-b2bd-4a1c-91b7-8abb5256459d"},
+      "partuuid":"6c85beff-b2bd-4a1c-91b7-8abb5256459d", "serial":"sda3123"},
       {"kname":"sda1", "model":null, "size":"209715200", "rota":false,
       "type":"part", "uuid":"0a83355d-7500-3f5f-9abd-66f6fd03714c",
-      "partuuid":"eba28b26-b76a-402c-94dd-0b66a523a485"},
+      "partuuid":"eba28b26-b76a-402c-94dd-0b66a523a485", "serial":"sda1123"},
       {"kname":"dm-0", "model":null, "size":"60022480896", "rota":false,
-      "type":"mpath", "uuid":null, "partuuid":null},
+      "type":"mpath", "serial":null, "uuid":null, "partuuid":null},
       {"kname":"dm-4", "model":null, "size":"650002432", "rota":false,
       "type":"part", "uuid":"b3b03565-5f13-3c93-b2a6-6d90e25be926",
-      "partuuid":"6c85beff-b2bd-4a1c-91b7-8abb5256459d"},
+      "partuuid":"6c85beff-b2bd-4a1c-91b7-8abb5256459d", "serial":null},
       {"kname":"dm-2", "model":null, "size":"209715200", "rota":false,
       "type":"part", "uuid":"0a83355d-7500-3f5f-9abd-66f6fd03714c",
-      "partuuid":"eba28b26-b76a-402c-94dd-0b66a523a485"},
+      "partuuid":"eba28b26-b76a-402c-94dd-0b66a523a485", "serial":null},
       {"kname":"dm-3", "model":null, "size":"59162722304", "rota":false,
       "type":"part", "uuid":"f8b55d59-96c3-3982-b129-1b6b2ee8da86",
-      "partuuid":"c97c8aac-7796-4433-b1fc-9b5fac43edf3"},
+      "partuuid":"c97c8aac-7796-4433-b1fc-9b5fac43edf3", "serial":null},
       {"kname":"sdb", "model":"INTEL_SSDSC2CT060A3", "size":"60022480896",
-      "rota":false, "type":"disk", "uuid":null, "partuuid":null},
+      "rota":false, "type":"disk", "serial":"sdb123", "uuid":null,
+      "partuuid":null},
       {"kname":"sdb2", "model":null, "size":"59162722304",
-      "rota":false, "type":"part",
+      "rota":false, "type":"part", "serial":"sdb2123",
       "uuid":"f8b55d59-96c3-3982-b129-1b6b2ee8da86",
       "partuuid":"c97c8aac-7796-4433-b1fc-9b5fac43edf3"},
       {"kname":"sdb3", "model":null, "size":"650002432",
-      "rota":false, "type":"part",
+      "rota":false, "type":"part", "serial":"sdv3123",
       "uuid":"b3b03565-5f13-3c93-b2a6-6d90e25be926",
       "partuuid":"6c85beff-b2bd-4a1c-91b7-8abb5256459d"},
       {"kname":"sdb1", "model":null, "size":"209715200",
-      "rota":false, "type":"part",
+      "rota":false, "type":"part", "serial":"sdb1123",
       "uuid":"0a83355d-7500-3f5f-9abd-66f6fd03714c",
       "partuuid":"eba28b26-b76a-402c-94dd-0b66a523a485"},
       {"kname":"sdc", "model":"ST1000DM003-1CH162", "size":"1000204886016",
-      "rota":true, "type":"disk", "uuid":null, "partuuid":null},
+      "rota":true, "type":"disk", "serial":"sdc123", "uuid":null,
+      "partuuid":null},
       {"kname":"sdc1", "model":null, "size":"899999072256",
-      "rota":true, "type":"part",
+      "rota":true, "type":"part", "serial":"sdc1123",
       "uuid":"457f7d3c-9376-4997-89bd-d1a7c8b04060",
       "partuuid":"c9433d2e-3bbc-47b4-92bf-43c1d80f06e0"},
       {"kname":"dm-1", "model":null, "size":"1000204886016", "rota":false,
-      "type":"mpath", "uuid":null, "partuuid":null}
+      "type":"mpath", "serial":null, "uuid":null, "partuuid":null}
     ]
 }
 """)
@@ -231,9 +250,10 @@ PARTUUID_DEVICE_TEMPLATE = ("""
 {
     "blockdevices": [
       {"kname":"sda", "model":"DRIVE 0", "size":1765517033472, "rota":true,
-      "type":"disk", "uuid":null, "partuuid":null},
+      "type":"disk", "serial":"sda123", "uuid":null, "partuuid":null},
       {"kname":"sda1", "model":"DRIVE 0", "size":107373133824, "rota":true,
-      "type":"part", "uuid":"987654-3210", "partuuid":"1234-5678"}
+      "type":"part", "serial":"sda1123", "uuid":"987654-3210",
+      "partuuid":"1234-5678"}
     ]
 }
 """)
@@ -1667,3 +1687,33 @@ MULTIPATH_LINKS_DM = (
     ' `-+- policy=\'service-time 0\' prio=1 status=active\n'
     '  `- 0:0:0:0 device s  8:0  active ready running\n'
 )
+
+LSBLK_OUPUT = ("""
+NAME="sda" TYPE="disk" FSTYPE=""
+NAME="sdb" TYPE="disk" FSTYPE=""
+""")
+
+LSBLK_OUPUT_ESP_RAID = ("""
+NAME="sda" TYPE="disk" FSTYPE=""
+NAME="sda1" TYPE="part" FSTYPE="linux_raid_member"
+NAME="md127" TYPE="raid1" FSTYPE=""
+NAME="md127p1" TYPE="md" FSTYPE="xfs"
+NAME="md127p2" TYPE="md" FSTYPE="iso9660"
+NAME="md127p14" TYPE="md" FSTYPE=""
+NAME="md127p15" TYPE="md" FSTYPE=""
+NAME="sda2" TYPE="part" FSTYPE="linux_raid_member"
+NAME="md126" TYPE="raid0" FSTYPE=""
+NAME="sda3" TYPE="part" FSTYPE="linux_raid_member"
+NAME="md125" TYPE="raid1" FSTYPE="vfat"
+NAME="sdb" TYPE="disk" FSTYPE=""
+NAME="sdb1" TYPE="part" FSTYPE="linux_raid_member"
+NAME="md127" TYPE="raid1" FSTYPE=""
+NAME="md127p1" TYPE="md" FSTYPE="xfs"
+NAME="md127p2" TYPE="md" FSTYPE="iso9660"
+NAME="md127p14" TYPE="md" FSTYPE=""
+NAME="md127p15" TYPE="md" FSTYPE=""
+NAME="sdb2" TYPE="part" FSTYPE="linux_raid_member"
+NAME="md126" TYPE="raid0" FSTYPE=""
+NAME="sdb3" TYPE="part" FSTYPE="linux_raid_member"
+NAME="md125" TYPE="raid1" FSTYPE="vfat"
+""")
